PALM-meteo: palmmeteo_stdplugins.meteo.SomeMeteoPlugin Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Public Member Functions | List of all members
palmmeteo_stdplugins.meteo.SomeMeteoPlugin Class Reference
Inheritance diagram for palmmeteo_stdplugins.meteo.SomeMeteoPlugin:
[legend]
Collaboration diagram for palmmeteo_stdplugins.meteo.SomeMeteoPlugin:
[legend]

## Classes
class | Provides

## Public Member Functions
| import_data (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.Plugin
| check_config (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
| __new__ (cls, name, bases, dct)

## Member Function Documentation

## ◆ import_data()

palmmeteo_stdplugins.meteo.SomeMeteoPlugin.import_data | ( |  | self,
|  | * | args,
|  | ** | kwargs
| ) |  |

Reimplemented from palmmeteo.plugins.ImportPluginMixin.

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/meteo.py